﻿using System;
using System.Linq;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows.Shapes;
using Telerik.Windows.Documents.Layout;
using Telerik.Windows.Documents.Model;
using Telerik.Windows.Documents.UI.Layers;

namespace SilverlightApplication1
{
    internal class SelectedSectionsLayer : DecorationUILayerBase
    {
        private static readonly double StrokeThikness = 1.0;
        private static readonly Brush StrokeBrush = new SolidColorBrush(Color.FromArgb(140, 60, 60, 60));
        private static readonly Brush FillBrush = new SolidColorBrush(Color.FromArgb(60, 140, 140, 140));

        public override string Name
        {
            get
            {
                return "SelectedSectionsLayer";
            }
        }

        public override void UpdateUIViewPortOverride(UILayerUpdateContext context)
        {
            foreach (SectionLayoutBox sectionLayoutBox in context.GetVisibleLayoutBoxes<SectionLayoutBox>())
            {
                if (sectionLayoutBox.AssociatedSection.IsSectionSelected())
                {
                    this.AddRectangle(sectionLayoutBox.BoundingRectangle);
                }
            }
        }

        private void AddRectangle(RectangleF rect)
        {
            Rectangle rectangle = new Rectangle();
            rectangle.Width = Math.Max(0, rect.Width + 2 * StrokeThikness);
            rectangle.Height = rect.Height + 2 * StrokeThikness;

            rectangle.Fill = FillBrush;
            rectangle.Stroke = StrokeBrush;
            rectangle.StrokeThickness = StrokeThikness;

            Canvas.SetTop(rectangle, rect.Top - StrokeThikness);
            Canvas.SetLeft(rectangle, rect.Left - StrokeThikness);
            base.AddDecorationElement(rectangle);
        }
    }

}
